﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Collections.ObjectModel;
using System.ComponentModel.DataAnnotations;
using System.Drawing;

namespace FlexGridIntro
{
    public class Person
    {
        internal static string[] Countries = "China|India|United States|Indonesia|Brazil|Pakistan|Bangladesh|Nigeria|Russia|Japan|Mexico|Philippines|Vietnam|Germany|Ethiopia|Egypt|Iran|Turkey|Congo|France|Thailand|United Kingdom|Italy|Myanmar".Split('|');

        #region ctor

        public Person(int id)
        {
            ID = id;
        }

        #endregion

        #region Object Model
        [DefaultValue(12)]
        public int ID { get; set; }
        [Required]
        [RegularExpression(pattern: "^[a-zA-Z0-9]{4,10}$", ErrorMessage = "The username must be alphanumeric and contains 4 to 10 characters.")]
        public string Name { get { return string.Format("{0} {1}", First, Last); } }
        [Required]
        public string Country { get { return Countries[CountryID]; } }
        [Required]
        public int CountryID { get; set; }
        [Required]
        public bool Active { get; set; }
        [Required]
        public string First { get; set; }
        [Required]
        public string Last { get; set; }
        [Required]
        public DateTime Hired { get; set; }
        public string Email { get; set; }
        public double Salery { get; set; }
        public string Dependent { get; set; }

        #endregion
    }

    public class SampleData
    {
        private static Random _rnd = new Random();
        private static string[] _firstNames = "Andy|Ben|Charlie|Dan|Ed|Fred|Gil|Herb|Jack|Karl|Larry|Mark|Noah|Oprah|Paul|Quince|Rich|Steve|Ted|Ulrich|Vic|Xavier|Zeb".Split('|');
        private static string[] _lastNames = "Ambers|Bishop|Cole|Danson|Evers|Frommer|Griswold|Heath|Jammers|Krause|Lehman|Myers|Neiman|Orsted|Paulson|Quaid|Richards|Stevens|Trask|Ulam".Split('|');

        private static string GetString(string[] arr)
        {
            return arr[_rnd.Next(arr.Length)];
        }

        public static IEnumerable<Person> GetData()
        {
            //Math.Min(_firstNames.Length,Person.Countries.Length)
            var list = Enumerable.Range(0, 10).Select(i =>
            {
                return new Person(i)
                {
                    First = _firstNames[i%_firstNames.Length],
                    Last = _lastNames[i%_lastNames.Length],
                    CountryID = (_rnd.Next(0, Person.Countries.Length) ),
                    Active = _rnd.NextDouble() >= .5,
                    Hired = DateTime.Today.AddDays(-_rnd.Next(1, 365)),
                    Salery=_rnd.NextDouble()*1000,
                    Dependent=_rnd.Next(0,8).ToString(),
                    Email= _firstNames[i % _firstNames.Length]+"."+ _lastNames[i % _lastNames.Length]+"@test.com"
                };
            });
            return list;
        }
    }
}
